% p-T phase diagram based on PP amplitudes of Ba-122
clear all
close all
%% load experimental data

A_8K = load('sat_A_3.txt', '-ascii'); % the dataset is extended by adding zeros in the metallic phase
A_pT = load('All_points_4.txt', '-ascii'); % the dataset is extended by adding zeros in the metallic phase
Ao_pT = load('All_points_2.txt', '-ascii'); % the original dataset

p = A_pT(:,2);
T = A_pT(:,3);
A = A_pT(:,5);

po = Ao_pT(:,2);
To = Ao_pT(:,3);
Ao = Ao_pT(:,5);

%% plotting original data

figure(1)
hold on
plot3(p,T,zeros(length(A),1),'*r')
% axis([-4, 4, -4, 4, 0, 25]);
grid
stem3(p,T,A,'^','fill')
hold off
view(322.5, 30);

%% interpolation onto a regular grid

px = 0.5:0.1:4.5;
Tx = 10:3.25:150;

A_LT = interp1(A_8K(:,1),A_8K(:,2),px); % interpolation of the horizontal scan to the same px values
A_LT = A_LT/max(A_LT); % normalizing 

X = [p T];
F = scatteredInterpolant(X,A,'linear'); 

%% interpolating and rescaling the values by the horizontal scan

for j=1:length(px),
    for k=1:length(Tx),
    A_interp(k,j) = F([px(j) Tx(k)])*A_LT(j);
    end;
end;

%% smoothing along T-axis

for j=1:length(px),
    A_smooth(:,j) = smooth(A_interp(:,j),7,'moving');
end;

%% plotting
figure(2)
hold on
surf(px,Tx,A_interp)
shading interp
view(2)
colormap('jet')
colorbar
xlabel('Pressure (GPa)')
ylabel('Temperature (K)')

% plotting original data points
plot3(p,T,zeros(length(A),1)+2,'*k')
hold off
% view(2);

%%
figure(3)
hold on
surf(px,Tx,A_smooth)
shading interp
view(2)
colormap('jet')
colorbar
xlabel('Pressure (GPa)')
ylabel('Temperature (K)')

% plotting original data points
plot3(po,To,zeros(length(Ao),1)+2,'*k')
hold off
% view(2);